class Chat:
    seed = 0

    def __init__(self, chat_name: str, chat_password: str, chat_admin_name: str):
        self.__chat_name = chat_name
        self.__chat_admin_name = chat_admin_name
        self.__chat_password = chat_password
        self.__members = [chat_admin_name]
        self.__messages_id = []

    def get_chat_name(self):
        return self.__chat_name

    def get_chat_password(self):
        return self.__chat_password

    def add_new_member(self, member_name):
        self.__members.append(member_name)

    def get_members(self):
        return self.__members

    def add_new_message_id(self, message_id):
        self.__messages_id.append(message_id)

    def to_json_object(self):
        return {"chat_name": self.__chat_name,
                "chat_admin_name": self.__chat_admin_name,
                "chat_password": self.__chat_password,
                "members": self.__members,
                "messages_id": self.__messages_id}

    @staticmethod
    def from_json_object(json_object):
        chat = Chat("", "", "")

        chat.__chat_name = json_object["chat_name"]
        chat.__chat_admin_name = json_object["chat_admin_name"]
        chat.__chat_password = json_object["chat_password"]
        chat.__members = json_object["chat_admin_name"]
        chat.__messages_id = json_object["messages_id"]

        return chat




import json
import os


class FileService:
    def __init__(self, file_path, data_list, object_class):
        path = os.path.join(file_path)

        self.__file_path = file_path
        self.__data_list = data_list

        if not os.path.isfile(path):
            my_file = open(file_path, "w")
            my_file.write("[]")
            my_file.close()
        else:
            with open(self.__file_path, "r") as file:
                json_array = json.load(file)
                for json_object in json_array:
                    self.__data_list.append(object_class.from_json_object(json_object))

                print(self.__data_list)

    def save_data(self):
        with open(self.__file_path, "w") as file:
            json_array = []
            for el in self.__data_list:
                json_array.append(el.to_json_object())
            # print(json_array)
            json.dump(json_array, file)



from datetime import datetime


class Message:
    def __init__(self, sender_name, message_text):
        self.__sender_name = sender_name
        self.__send_date = datetime.now()
        self.__message_text = message_text

    def get_sender_name(self):
        return self.__sender_name

    def get_send_date(self):
        return self.__send_date

    def get_message_text(self):
        return self.__message_text

    def to_json_object(self):
        return {"sender_name": self.__sender_name,
                "send_date": self.__send_date.strftime("%Y-%m-%d %H:%M:%S"),
                "message_text": self.__message_text}

    @staticmethod
    def from_json_object(json_object):
        message = Message("", "")
        message.__sender_name = json_object["sender_name"]
        message.__send_date = datetime.strptime(json_object["send_date"], "%Y-%m-%d %H:%M:%S")
        message.__message_text = json_object["message_text"]

        return message



from setuptools import setup, find_packages


setup(
    name="lib_for_messanger",
    version="0.4",
    description="library for my messenger",
    url="https://github.com/VPG1/lib_for_messanger",
    author="Kirill Malihtorovich",
    author_email="mmalihtorovic@gmail.com",
    classifiers=[
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3.10",
        "Operating System :: OS Independent"
    ],
    packages=["lib_for_messanger"]
)



class User:
    def __init__(self, name, password):
        self.__name = name
        self.__password = password
        self.__chats = []

    def set_name(self, name):
        self.__name = name

    def get_name(self):
        return self.__name

    def get_password(self):
        return self.__password

    def join_to_chat(self, chat_name):
        self.__chats.append(chat_name)

    def to_json_object(self):
        return {"name": self.__name,
                "password": self.__password,
                "chats": self.__chats}

    @staticmethod
    def from_json_object(json_object):
        user = User("", "")
        user.__name = json_object["name"]
        user.__password = json_object["password"]
        user.__chatsId = json_object["chats"]

        return user
